## Not run:
# # Using the 'record' parameter
# # Create 'record' object with values
# rec <- list(decimalLatitude=42.1833, decimalLongitude=-1.8332,
# countryCode="ES", scientificName="Puma concolor")
# # Call the API and get the results
# parse_record(record=rec)
#
# # Using named arguments
# parse_record(decimalLatitude=42.1833, decimalLongitude=-1.8332,
# countryCode="ES", scientificName="Puma concolor")
# # In both cases, the result will be the same
#
# # If any parameter is missing, the function runs, but throws a warning
# # message. This will throw a warning saying that 'countryCode' and
# # 'scientificName' fields are missing. Also, the results will be
# # limited to the feasible calculations.
# parse_record(decimalLatitude=42.1833, decimalLongitude=-1.8332)
#
# # One can call the function without parameters. Although valid,
# # this way of calling the function is useless.
# parse_record()
# ## End(Not run)
Run the code above in your browser using DataLab